@@ -12,7 +12,9 @@ from DependencyParser.ParserEvaluationScore import ParserEvaluationScore
 
 class AnnotatedCorpus(Corpus):
 
-    def __init__(self, folder: str, pattern: str = None):
+    def __init__(self,
+                 folder: str,
+                 pattern: str = None):
         """
         A constructor of AnnotatedCorpus class which reads all AnnotatedSentence files with the file
         name satisfying the given pattern inside the given folder. For each file inside that folder, the constructor
@@ -28,10 +30,10 @@ class AnnotatedCorpus(Corpus):
         self.sentences = []
         for root, dirs, files in os.walk(folder):
             for file in files:
-                fileName = os.path.join(root, file)
-                if (pattern is None or pattern in fileName) and re.match("\\d+\\.", file):
-                    f = open(fileName, "r", encoding='utf8')
-                    sentence = AnnotatedSentence(f, fileName)
+                file_name = os.path.join(root, file)
+                if (pattern is None or pattern in file_name) and re.match("\\d+\\.", file):
+                    f = open(file_name, "r", encoding='utf8')
+                    sentence = AnnotatedSentence(f, file_name)
                     self.sentences.append(sentence)
 
     def compareParses(self, corpus: AnnotatedCorpus) -> ParserEvaluationScore:
@@ -42,7 +44,9 @@ class AnnotatedCorpus(Corpus):
             result.add(sentence1.compareParses(sentence2))
         return result
 
-    def exportUniversalDependencyFormat(self, outputFileName: str, path: str = None):
+    def exportUniversalDependencyFormat(self,
+                                        outputFileName: str,
+                                        path: str = None):
         file = open(outputFileName, "w")
         for i in range(self.sentenceCount()):
             sentence = self.getSentence(i)
