@@ -3,10 +3,12 @@ from Corpus.Sentence import Sentence
 
 class AnnotatedPhrase(Sentence):
 
-    __wordIndex: int
+    __word_index: int
     __tag: str
 
-    def __init__(self, wordIndex: int, tag: str):
+    def __init__(self,
+                 wordIndex: int,
+                 tag: str):
         """
         Constructor for AnnotatedPhrase. AnnotatedPhrase stores information about phrases such as
         Shallow Parse phrases or named entity phrases.
@@ -19,7 +21,7 @@ class AnnotatedPhrase(Sentence):
             Tag of the phrase. Corresponds to the shallow parse or named entity tag.
         """
         super().__init__()
-        self.__wordIndex = wordIndex
+        self.__word_index = wordIndex
         self.__tag = tag
 
     def getWordIndex(self) -> int:
@@ -31,7 +33,7 @@ class AnnotatedPhrase(Sentence):
         int
             Starting index of the first word in the phrase w.r.t. original sentence the phrase occurs.
         """
-        return self.__wordIndex
+        return self.__word_index
 
     def getTag(self) -> str:
         """
