@@ -14,9 +14,11 @@ from AnnotatedSentence.AnnotatedWord import AnnotatedWord
 
 class AnnotatedSentence(Sentence):
 
-    __fileName: str
+    __file_name: str
 
-    def __init__(self, fileOrStr=None, fileName=None):
+    def __init__(self,
+                 fileOrStr=None,
+                 fileName=None):
         """
         Converts a simple sentence to an annotated sentence
 
@@ -26,17 +28,17 @@ class AnnotatedSentence(Sentence):
             Simple sentence
         """
         self.words = []
-        wordArray = []
+        word_array = []
         if fileOrStr is not None:
             if fileName is not None:
-                self.__fileName = fileName
+                self.__file_name = fileName
             if isinstance(fileOrStr, TextIOWrapper):
                 line = fileOrStr.readline()
                 fileOrStr.close()
-                wordArray = line.rstrip().split(" ")
+                word_array = line.rstrip().split(" ")
             elif isinstance(fileOrStr, str):
-                wordArray = fileOrStr.split(" ")
-            for word in wordArray:
+                word_array = fileOrStr.split(" ")
+            for word in word_array:
                 if len(word) > 0:
                     self.words.append(AnnotatedWord(word))
 
@@ -49,23 +51,23 @@ class AnnotatedSentence(Sentence):
         list
             Shallow parse groups of a sentence.
         """
-        shallowParseGroups = []
-        previousWord = None
+        shallow_parse_groups = []
+        previous_word = None
         current = None
         for i in range(self.wordCount()):
             word = self.getWord(i)
             if isinstance(word, AnnotatedWord):
-                if previousWord is None:
+                if previous_word is None:
                     current = AnnotatedPhrase(i, word.getShallowParse())
                 else:
-                    if isinstance(previousWord, AnnotatedWord) and previousWord.getShallowParse() is not None \
-                            and previousWord.getShallowParse() != word.getShallowParse():
-                        shallowParseGroups.append(current)
+                    if isinstance(previous_word, AnnotatedWord) and previous_word.getShallowParse() is not None \
+                            and previous_word.getShallowParse() != word.getShallowParse():
+                        shallow_parse_groups.append(current)
                         current = AnnotatedPhrase(i, word.getShallowParse())
                 current.addWord(word)
-                previousWord = word
-        shallowParseGroups.append(current)
-        return shallowParseGroups
+                previous_word = word
+        shallow_parse_groups.append(current)
+        return shallow_parse_groups
 
     def containsPredicate(self) -> bool:
         """
@@ -83,7 +85,9 @@ class AnnotatedSentence(Sentence):
                     return True
         return False
 
-    def updateConnectedPredicate(self, previousId: str, currentId: str) -> bool:
+    def updateConnectedPredicate(self,
+                                 previousId: str,
+                                 currentId: str) -> bool:
         modified = False
         for word in self.words:
             if isinstance(word, AnnotatedWord):
@@ -114,22 +118,22 @@ class AnnotatedSentence(Sentence):
         -------
         A list of words, which are verbs, semantic tags assigned, and framesetlist assigned for that tag.
         """
-        candidateList = []
+        candidate_list = []
         for word in self.words:
             if isinstance(word, AnnotatedWord):
                 if word.getParse() is not None and word.getParse().isVerb() and word.getSemantic() is not None \
                         and framesetList.frameExists(word.getSemantic()):
-                    candidateList.append(word)
+                    candidate_list.append(word)
         for i in range(2):
             for j in range(len(self.words) - i - 1):
-                annotatedWord = self.words[j]
-                nextAnnotatedWord = self.words[j + 1]
-                if isinstance(annotatedWord, AnnotatedWord) and isinstance(nextAnnotatedWord, AnnotatedWord):
-                    if annotatedWord not in candidateList and nextAnnotatedWord in candidateList \
-                            and annotatedWord.getSemantic() is not None \
-                            and annotatedWord.getSemantic() == nextAnnotatedWord.getSemantic():
-                        candidateList.append(annotatedWord)
-        return candidateList
+                annotated_word = self.words[j]
+                next_annotated_word = self.words[j + 1]
+                if isinstance(annotated_word, AnnotatedWord) and isinstance(next_annotated_word, AnnotatedWord):
+                    if annotated_word not in candidate_list and next_annotated_word in candidate_list \
+                            and annotated_word.getSemantic() is not None \
+                            and annotated_word.getSemantic() == next_annotated_word.getSemantic():
+                        candidate_list.append(annotated_word)
+        return candidate_list
 
     def predicateFrameCandidates(self, frameNet: FrameNet) -> list:
         """
@@ -147,22 +151,22 @@ class AnnotatedSentence(Sentence):
         -------
         A list of words, which are verbs, semantic tags assigned, and frame assigned for that tag.
         """
-        candidateList = []
+        candidate_list = []
         for word in self.words:
             if isinstance(word, AnnotatedWord):
                 if word.getParse() is not None and word.getParse().isVerb() and word.getSemantic() is not None \
                         and frameNet.lexicalUnitExists(word.getSemantic()):
-                    candidateList.append(word)
+                    candidate_list.append(word)
         for i in range(2):
             for j in range(len(self.words) - i - 1):
-                annotatedWord = self.words[j]
-                nextAnnotatedWord = self.words[j + 1]
-                if isinstance(annotatedWord, AnnotatedWord) and isinstance(nextAnnotatedWord, AnnotatedWord):
-                    if annotatedWord not in candidateList and nextAnnotatedWord in candidateList \
-                            and annotatedWord.getSemantic() is not None \
-                            and annotatedWord.getSemantic() == nextAnnotatedWord.getSemantic():
-                        candidateList.append(annotatedWord)
-        return candidateList
+                annotated_word = self.words[j]
+                next_annotated_word = self.words[j + 1]
+                if isinstance(annotated_word, AnnotatedWord) and isinstance(next_annotated_word, AnnotatedWord):
+                    if annotated_word not in candidate_list and next_annotated_word in candidate_list \
+                            and annotated_word.getSemantic() is not None \
+                            and annotated_word.getSemantic() == next_annotated_word.getSemantic():
+                        candidate_list.append(annotated_word)
+        return candidate_list
 
     def getPredicate(self, index: int) -> str:
         """
@@ -212,7 +216,7 @@ class AnnotatedSentence(Sentence):
         str
             File name of the sentence
         """
-        return self.__fileName
+        return self.__file_name
 
     def removeWord(self, index: int):
         """
@@ -236,17 +240,17 @@ class AnnotatedSentence(Sentence):
              String result which has all the stems of each item in words {@link ArrayList}.
         """
         if len(self.words) > 0:
-            annotatedWord = self.words[0]
-            if annotatedWord.getParse() is not None:
-                result = annotatedWord.getParse().getWord().getName()
+            annotated_word = self.words[0]
+            if annotated_word.getParse() is not None:
+                result = annotated_word.getParse().getWord().getName()
             else:
-                result = annotatedWord.getName()
+                result = annotated_word.getName()
             for i in range(1, len(self.words)):
-                annotatedWord = self.words[i]
-                if annotatedWord.getParse() is not None:
-                    result = result + " " + annotatedWord.getParse().getWord().getName()
+                annotated_word = self.words[i]
+                if annotated_word.getParse() is not None:
+                    result = result + " " + annotated_word.getParse().getWord().getName()
                 else:
-                    result = result + " " + annotatedWord.getName()
+                    result = result + " " + annotated_word.getName()
             return result
         else:
             return ""
@@ -264,7 +268,7 @@ class AnnotatedSentence(Sentence):
         """
         Saves the current sentence.
         """
-        self.writeToFile(self.__fileName)
+        self.writeToFile(self.__file_name)
 
     def getUniversalDependencyFormat(self, path: str = None) -> str:
         if path is None:
@@ -300,32 +304,40 @@ class AnnotatedSentence(Sentence):
             List of literal candidates containing all possible root forms and multiword expressions.
         """
         word = self.getWord(wordIndex)
-        possibleLiterals = []
+        possible_literals = []
         if isinstance(word, AnnotatedWord):
-            morphologicalParse = word.getParse()
-            metamorphicParse = word.getMetamorphicParse()
-            possibleLiterals.extend(wordNet.constructLiterals(morphologicalParse.getWord().getName(),
-                                                              morphologicalParse, metamorphicParse, fsm))
-            firstSucceedingWord = None
-            secondSucceedingWord = None
+            morphological_parse = word.getParse()
+            metamorphic_parse = word.getMetamorphicParse()
+            possible_literals.extend(wordNet.constructLiterals(morphological_parse.getWord().getName(),
+                                                               morphological_parse,
+                                                               metamorphic_parse,
+                                                               fsm))
+            first_succeeding_word = None
+            second_succeeding_word = None
             if self.wordCount() > wordIndex + 1:
-                firstSucceedingWord = self.getWord(wordIndex + 1)
+                first_succeeding_word = self.getWord(wordIndex + 1)
                 if self.wordCount() > wordIndex + 2:
-                    secondSucceedingWord = self.getWord(wordIndex + 2)
-            if firstSucceedingWord is not None and isinstance(firstSucceedingWord, AnnotatedWord):
-                if secondSucceedingWord is not None and isinstance(secondSucceedingWord, AnnotatedWord):
-                    possibleLiterals.extend(wordNet.constructIdiomLiterals(fsm, word.getParse(),
-                                                                           word.getMetamorphicParse(),
-                                                                           firstSucceedingWord.getParse(),
-                                                                           firstSucceedingWord.getMetamorphicParse(),
-                                                                           secondSucceedingWord.getParse(),
-                                                                           secondSucceedingWord.getMetamorphicParse()))
-                possibleLiterals.extend(wordNet.constructIdiomLiterals(fsm, word.getParse(), word.getMetamorphicParse(),
-                                                                       firstSucceedingWord.getParse(),
-                                                                       firstSucceedingWord.getMetamorphicParse()))
-        return possibleLiterals
+                    second_succeeding_word = self.getWord(wordIndex + 2)
+            if first_succeeding_word is not None and isinstance(first_succeeding_word, AnnotatedWord):
+                if second_succeeding_word is not None and isinstance(second_succeeding_word, AnnotatedWord):
+                    possible_literals.extend(wordNet.constructIdiomLiterals(fsm,
+                                                                            word.getParse(),
+                                                                            word.getMetamorphicParse(),
+                                                                            first_succeeding_word.getParse(),
+                                                                            first_succeeding_word.getMetamorphicParse(),
+                                                                            second_succeeding_word.getParse(),
+                                                                            second_succeeding_word.getMetamorphicParse()))
+                possible_literals.extend(wordNet.constructIdiomLiterals(fsm,
+                                                                        word.getParse(),
+                                                                        word.getMetamorphicParse(),
+                                                                        first_succeeding_word.getParse(),
+                                                                        first_succeeding_word.getMetamorphicParse()))
+        return possible_literals
 
-    def constructSynSets(self, wordNet: WordNet, fsm: FsmMorphologicalAnalyzer, wordIndex: int) -> list:
+    def constructSynSets(self,
+                         wordNet: WordNet,
+                         fsm: FsmMorphologicalAnalyzer,
+                         wordIndex: int) -> list:
         """
         Creates a list of synset candidates for the i'th word in the sentence. It combines the results of
         1. All possible synsets containing the i'th word in the sentence
@@ -347,43 +359,45 @@ class AnnotatedSentence(Sentence):
             List of synset candidates containing all possible root forms and multiword expressions.
         """
         word = self.getWord(wordIndex)
-        possibleSynSets = []
+        possible_syn_sets = []
         if isinstance(word, AnnotatedWord):
-            morphologicalParse = word.getParse()
-            metamorphicParse = word.getMetamorphicParse()
-            possibleSynSets.extend(wordNet.constructSynSets(morphologicalParse.getWord().getName(),
-                                                            morphologicalParse, metamorphicParse, fsm))
-            firstPrecedingWord = None
-            secondPrecedingWord = None
-            firstSucceedingWord = None
-            secondSucceedingWord = None
+            morphological_parse = word.getParse()
+            metamorphic_parse = word.getMetamorphicParse()
+            possible_syn_sets.extend(wordNet.constructSynSets(morphological_parse.getWord().getName(),
+                                                              morphological_parse,
+                                                              metamorphic_parse,
+                                                              fsm))
+            first_preceding_word = None
+            second_preceding_word = None
+            first_succeeding_word = None
+            second_succeeding_word = None
             if wordIndex > 0:
-                firstPrecedingWord = self.getWord(wordIndex - 1)
+                first_preceding_word = self.getWord(wordIndex - 1)
                 if wordIndex > 1:
-                    secondPrecedingWord = self.getWord(wordIndex - 2)
+                    second_preceding_word = self.getWord(wordIndex - 2)
             if self.wordCount() > wordIndex + 1:
-                firstSucceedingWord = self.getWord(wordIndex + 1)
+                first_succeeding_word = self.getWord(wordIndex + 1)
                 if self.wordCount() > wordIndex + 2:
-                    secondSucceedingWord = self.getWord(wordIndex + 2)
-            if firstPrecedingWord is not None and isinstance(firstPrecedingWord, AnnotatedWord):
-                if secondPrecedingWord is not None and isinstance(secondPrecedingWord, AnnotatedWord):
-                    possibleSynSets.extend(wordNet.constructIdiomSynSets(fsm, secondPrecedingWord.getParse(),
-                                                                         secondPrecedingWord.getMetamorphicParse(),
-                                                                         firstPrecedingWord.getParse(),
-                                                                         firstPrecedingWord.getMetamorphicParse(),
+                    second_succeeding_word = self.getWord(wordIndex + 2)
+            if first_preceding_word is not None and isinstance(first_preceding_word, AnnotatedWord):
+                if second_preceding_word is not None and isinstance(second_preceding_word, AnnotatedWord):
+                    possible_syn_sets.extend(wordNet.constructIdiomSynSets(fsm, second_preceding_word.getParse(),
+                                                                         second_preceding_word.getMetamorphicParse(),
+                                                                         first_preceding_word.getParse(),
+                                                                         first_preceding_word.getMetamorphicParse(),
                                                                          word.getParse(), word.getMetamorphicParse()))
-                possibleSynSets.extend(wordNet.constructIdiomSynSets(fsm, firstPrecedingWord.getParse(),
-                                                                     firstPrecedingWord.getMetamorphicParse(),
+                possible_syn_sets.extend(wordNet.constructIdiomSynSets(fsm, first_preceding_word.getParse(),
+                                                                     first_preceding_word.getMetamorphicParse(),
                                                                      word.getParse(), word.getMetamorphicParse()))
-            if firstSucceedingWord is not None and isinstance(firstSucceedingWord, AnnotatedWord):
-                if secondSucceedingWord is not None and isinstance(secondSucceedingWord, AnnotatedWord):
-                    possibleSynSets.extend(wordNet.constructIdiomSynSets(fsm, word.getParse(),
+            if first_succeeding_word is not None and isinstance(first_succeeding_word, AnnotatedWord):
+                if second_succeeding_word is not None and isinstance(second_succeeding_word, AnnotatedWord):
+                    possible_syn_sets.extend(wordNet.constructIdiomSynSets(fsm, word.getParse(),
                                                                          word.getMetamorphicParse(),
-                                                                         firstSucceedingWord.getParse(),
-                                                                         firstSucceedingWord.getMetamorphicParse(),
-                                                                         secondSucceedingWord.getParse(),
-                                                                         secondSucceedingWord.getMetamorphicParse()))
-                possibleSynSets.extend(wordNet.constructIdiomSynSets(fsm, word.getParse(), word.getMetamorphicParse(),
-                                                                     firstSucceedingWord.getParse(),
-                                                                     firstSucceedingWord.getMetamorphicParse()))
-        return possibleSynSets
+                                                                         first_succeeding_word.getParse(),
+                                                                         first_succeeding_word.getMetamorphicParse(),
+                                                                         second_succeeding_word.getParse(),
+                                                                         second_succeeding_word.getMetamorphicParse()))
+                possible_syn_sets.extend(wordNet.constructIdiomSynSets(fsm, word.getParse(), word.getMetamorphicParse(),
+                                                                     first_succeeding_word.getParse(),
+                                                                     first_succeeding_word.getMetamorphicParse()))
+        return possible_syn_sets
